==> netbeans_8.0.2%2Bdfsg1.orig.tar.xz: netbeans-8.0.2/editor.lib2/src/org/netbeans/modules/editor/lib2/highlighting/HighlightItem.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.editor.lib2.highlighting;

import javax.swing.text.AttributeSet;

/**
 * Immutable single item for highlighting without a specified start (it's derived from end of previous item).
 *
 * @author Miloslav Metelka
 */
public final class HighlightItem {
    
    /** End offset of the highlight. Start offset is derived from end of previous item. */
    private final int endOffset; // 8 + 4 = 12 bytes

    /** Attributes of highlight. Null for no highlight in the particular area. */
    private final AttributeSet attrs; // 12 + 4 = 16 bytes

    public HighlightItem(int endOffset, AttributeSet attrs) {
        this.endOffset = endOffset;
        this.attrs = attrs;
    }
  
    /**
     * End offset of the highlighting item.
     * 
     * @return end offset of the highlight
     */
    public int getEndOffset() {
        return endOffset;
    }

    /**
     * Attributes of the highlight.
     *
     * @return attributes or null if this area has no highlighting.
     */
    public AttributeSet getAttributes() {
        return attrs;
    }

    @Override
    public String toString() {
        return "<?," + endOffset + ">: " + attrs; // NOI18N
    }

    public String toString(int startOffset) {
        return "<" + startOffset + "," + endOffset + ">: " + attrs; // NOI18N
    }

}

==> netbeans_8.2%2Bdfsg1.orig.tar.xz: netbeans-8.2/editor.lib2/src/org/netbeans/modules/editor/lib2/highlighting/HighlightItem.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Sun Microsystems, Inc.
 */

package org.netbeans.modules.editor.lib2.highlighting;

import javax.swing.text.AttributeSet;

/**
 * Immutable single item for highlighting without a specified start (it's derived from end of previous item).
 *
 * @author Miloslav Metelka
 */
public class HighlightItem {
    
    /** End offset of the highlight. Start offset is derived from end of previous item. */
    private final int endOffset; // 8 + 4 = 12 bytes

    /** Attributes of highlight. Null for no highlight in the particular area. */
    private final AttributeSet attrs; // 12 + 4 = 16 bytes

    public HighlightItem(int endOffset, AttributeSet attrs) {
        this.endOffset = endOffset;
        this.attrs = attrs;
    }
  
    /**
     * End offset of the highlighting item.
     * 
     * @return end offset of the highlight
     */
    public int getEndOffset() {
        return endOffset;
    }
    
    public int getEndSplitOffset() {
        return 0;
    }

    /**
     * Attributes of the highlight.
     *
     * @return attributes or null if this area has no highlighting.
     */
    public AttributeSet getAttributes() {
        return attrs;
    }

    @Override
    public String toString() {
        return "<?," + endOffset + ">: " + attrs; // NOI18N
    }

    public String toString(int startOffset) {
        return "<" + startOffset + "," + endOffset + ">: " + attrs; // NOI18N
    }

}
